##  Step 1: Register SAP LeanIX in Microsoft Entra ID
  1. Based on the region, sign in to either the [Global Azure portal](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fportal.azure.com "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fportal.azure.com") or the [China Azure portal](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fportal.azure.cn "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fportal.azure.cn").
Use the Azure administrator account that is also a member of the Global Administrator directory role in your Microsoft Entra ID tenant.
  2. In the left navigation menu, choose Microsoft Entra ID.
  3. On the Microsoft Entra ID page, choose App Registrations.
  4. In the toolbar on the top of the app registrations page, choose New registration.
    1. Enter a name for the integration.
    2. Under Supported account types, select Accounts in this organizational directory only (MSFT only - Single tenant).
    3. Choose Register at the bottom of the screen.
![The Register an application form in Microsoft Entra admin center with fields for name and account types.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio59a71666f0064d9189a396eae2c59ddb_LowRes.png)
Registering an Application in Microsoft Entra ID
